@@ -54,6 +54,7 @@ sub get {
 				document_readonly => 'Write Protection',
 				view => 'View',
 				view_bars => 'App Bars',
+				view_panel => 'Panel',
 				view_contextmenu => 'Context Menus',
 				view_editpanel_contexmenu => 'Edit Panel',
 				view_textmargin => 'Text Margin',
@@ -84,6 +85,7 @@ sub get {
 			label => {
 				app => {
 					'exit' => 'Exit',
+					'exit-unsaved' => 'Exit Without Save',
 				},
 				file => {
 					new => 'New',
@@ -304,12 +306,17 @@ sub get {
 						ada => 'Ada',
 						as => 'Actionscript',
 						asm => 'Assembler',
-						c => 'C / C++',
+						ave => 'Avennue',
+						baan => 'Baan',
+						batch => 'Batch',
+						c => 'C | C++',
 						conf => 'Conf',
 						context => 'Context',
-						cs => 'C\#',
+						cs => 'C#',
 						css => 'CSS',
+						diff => 'Diff',
 						eiffel => 'Eiffel',
+						err => 'Errorlist',
 						forth => 'Forth',
 						fortran => 'FORTRAN',
 						html => 'HTML',
@@ -319,10 +326,13 @@ sub get {
 						latex => 'LaTeX',
 						lisp => 'LISP',
 						lua => 'Lua',
+						make => 'Makefile',
+						matlab => 'Matlab',
 						nsis => 'NSIS',
 						pascal => 'Pascal',
 						perl => 'Perl',
 						php => 'PHP',
+						property => 'Property',
 						ps => 'Postscript',
 						python => 'Python',
 						ruby => 'Ruby',
@@ -395,6 +405,10 @@ sub get {
 							},
 						},
 					},
+					panel => {
+						notepad => 'Notepad',
+						output => 'Output',
+					},
 					statusbar => 'Statusbar',
 					'statusbar-contexmenu' => 'Statuscontext',
 					'statusbar-info' => {
@@ -455,10 +469,10 @@ sub get {
 							ave => 'Avennue',
 							baan => 'Baan',
 							batch => 'Batch',
-							c => 'C / C++',
+							c => 'C | C++',
 							conf => 'Conf',
 							context => 'Context',
-							cs => 'C\#',
+							cs => 'C#',
 							css => 'CSS',
 							diff => 'Diff',
 							eiffel => 'Eiffel',
@@ -498,7 +512,8 @@ sub get {
 			},
 			help => {
 				app => {
-					'exit' => 'Exit',
+					'exit' => 'shut down the application and save settings and files',
+					'exit-unsaved' => 'shut down app without saving the open files',
 				},
 				file => {
 					new => 'opens a new empty text',
@@ -682,6 +697,11 @@ sub get {
 					},
 					'delete-all' => 'delete all bookmarks',
 				},
+				tool => {
+					note => 'jump to the notepad',
+					'run-document' => 'run current programm and show result in output panel',
+					'stop-document' => 'stop the current running output panel process',
+				},
 				document => {
 					'auto-indention' => 'indents new line like previous when Enter pressed ',
 					'brace-indention' => 'obey right indention after curly braces when press enter',
@@ -811,6 +831,10 @@ sub get {
 							},
 						},
 					},
+					panel => {
+						notepad => 'switch visibility of the Notepad panel',
+						output => 'switch visibility of the Output panel',
+					},
 					statusbar => 'switch visibility of the statusbar on bottom of the window',
 					'statusbar-contexmenu' => 'enable or disable context menus on statusbar',
 					'statusbar-info' => {
